@@ -14,15 +14,8 @@ from meutils.pipe import *
 from paddleocr import PaddleOCR
 from gooey import Gooey, GooeyParser
 
-# from PIL import Image, ImageGrab
-#
-# try:
-#     im = ImageGrab.grabclipboard()
-#     im.save("./默认读取截图")
-# except:
-#     pass
 
-ocr = PaddleOCR(use_angle_cls=True, lang="ch", use_gpu=False)
+ocr = PaddleOCR(use_angle_cls=True, lang="ch", use_gpu=False, show_log=False)
 
 
 @Gooey(
